@@ -15,12 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.17 2005/12/02 12:50:17 chpe Exp $
+ *  $Id: extensions-manager-ui.c,v 1.20 2006/03/12 14:15:59 chpe Exp $
  */
 
 #include "config.h"
 
 #include "extensions-manager-ui.h"
+
+#include "ephy-gui.h"
 #include "ephy-debug.h"
 
 #include <epiphany/ephy-extensions-manager.h>
@@ -38,6 +40,7 @@
 #include <string.h>
 
 #include <glib/gi18n-lib.h>
+#include <gtk/gtkversion.h>
 
 #define IGNORE_SELF /* Don't display *this* extension in the list */
 #define GROUP	"Epiphany Extension"
@@ -123,7 +126,7 @@ extensions_manager_ui_response_cb (GtkWidget *widget,
 {
 	if (response == GTK_RESPONSE_HELP)
 	{
-		/* FIXME not implemented yet */
+		ephy_gui_help (GTK_WINDOW (widget), "epiphany", "extending-epiphany");
 		return;
 	}
 
@@ -151,7 +154,16 @@ show_extension_info (ExtensionsManagerUI *parent_dialog,
 
 	gtk_window_set_transient_for (GTK_WINDOW (dialog),
 				      GTK_WINDOW (parent_dialog->priv->window));
-	/* FIXME window group ! */
+#if !GTK_CHECK_VERSION(2,9,0)
+	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (parent_dialog->priv->window)),
+				     GTK_WINDOW (dialog));
+#endif
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+
+#if GTK_CHECK_VERSION(2,9,0)
+	g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+#endif
+
 	gtk_window_present (GTK_WINDOW (dialog));
 
 	g_free (name);
@@ -176,7 +188,7 @@ store_extension (GtkListStore *store,
 	gtk_list_store_set (store, &iter,
 				COL_INFO, info,
 				COL_NAME, name,
-				COL_TOGGLE, info->active,
+				COL_TOGGLE, info->enabled,
 				COL_DISPLAY, display,
 				-1);
 
@@ -278,7 +290,7 @@ active_sync (EphyExtensionsManager *manager,
 		if (row_info == info)
 		{
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-					    COL_TOGGLE, info->active,
+					    COL_TOGGLE, info->enabled,
 					    -1);
 			break;
 		}
